@@ -218,16 +218,26 @@ class AbstractBuilder(ABC):
 
 	def copy_additional_files(self) -> None:  # pylint: disable=useless-return
 		"""
-		Copy additional files to the build directory, as specified in the ``additional_files`` key.
+		Copy additional files to the build directory, as specified in the ``additional-files`` key.
 		"""
 
+		self.parse_additional_files(*self.config["additional-files"])
+
+	def parse_additional_files(self, *entries: str) -> None:  # pylint: disable=useless-return
+		r"""
+		Copy additional files to the build directory,
+		by parsing `MANIFEST.in <https://packaging.python.org/guides/using-manifest-in/>`_-style entries.
+
+		:param \*entries:
+		"""  # noqa: D400
+
 		def copy_file(filename):
 			target = self.build_dir / filename.relative_to(self.project_dir)
 			target.parent.maybe_make(parents=True)
 			shutil.copy2(src=filename, dst=target)
 			self.report_copied(filename, target)
 
-		for entry in self.config["additional-files"]:
+		for entry in entries:
 			parts = entry.split(' ')
 
 			if parts[0] == "include":
